pub enum StandardVariable {
Show 47 variants
Abstract,
Annote,
Archive,
ArchiveCollection,
ArchiveLocation,
ArchivePlace,
Authority,
CallNumber,
CitationKey,
CitationLabel,
CollectionTitle,
ContainerTitle,
ContainerTitleShort,
Dimensions,
Division,
DOI,
Event,
EventTitle,
EventPlace,
Genre,
ISBN,
ISSN,
Jurisdiction,
Keyword,
Language,
License,
Medium,
Note,
OriginalPublisher,
OriginalPublisherPlace,
OriginalTitle,
PartTitle,
PMCID,
PMID,
Publisher,
PublisherPlace,
References,
ReviewedGenre,
ReviewedTitle,
Scale,
Source,
Status,
Title,
TitleShort,
URL,
VolumeTitle,
YearSuffix,
}Expand description
The set of variables with no other attributes.
Variants
Abstract
Abstract of the item (e.g. the abstract of a journal article).
Annote
Short markup, decoration, or annotation to the item (e.g., to indicate items included in a review); For descriptive text (e.g., in an annotated bibliography), use note instead.
Archive
Archive storing the item.
ArchiveCollection
Collection the item is part of within an archive.
ArchiveLocation
Storage location within an archive (e.g. a box and folder number).
ArchivePlace
Geographic location of the archive.
Authority
Issuing or judicial authority (e.g. “USPTO” for a patent, “Fairfax Circuit Court” for a legal case).
CallNumber
Call number (to locate the item in a library).
CitationKey
Identifier of the item in the input data file (analogous to BibTeX entrykey); Use this variable to facilitate conversion between word-processor and plain-text writing systems; For an identifier intended as formatted output label for a citation (e.g. “Ferr78”), use citation-label instead.
CitationLabel
Label identifying the item in in-text citations of label styles (e.g. “Ferr78”); May be assigned by the CSL processor based on item metadata; For the identifier of the item in the input data file, use citation-key instead.
CollectionTitle
Title of the collection holding the item (e.g. the series title for a book; the lecture series title for a presentation).
ContainerTitle
Title of the container holding the item (e.g. the book title for a book chapter, the journal title for a journal article; the album title for a recording; the session title for multi-part presentation at a conference).
ContainerTitleShort
Short/abbreviated form of container-title; Deprecated; use variable=“container-title” form=“short” instead.
Dimensions
Physical (e.g. size) or temporal (e.g. running time) dimensions of the item.
Division
Minor subdivision of a court with a jurisdiction for a legal item.
DOI
Digital Object Identifier (e.g. “10.1128/AEM.02591-07”).
Event
Deprecated legacy variant of event-title.
EventTitle
Name of the event related to the item (e.g. the conference name when citing a conference paper; the meeting where presentation was made).
EventPlace
Geographic location of the event related to the item (e.g. “Amsterdam, The Netherlands”).
Genre
Type, class, or subtype of the item (e.g. “Doctoral dissertation” for a PhD thesis; “NIH Publication” for an NIH technical report); Do not use for topical descriptions or categories (e.g. “adventure” for an adventure movie).
ISBN
International Standard Book Number (e.g. “978-3-8474-1017-1”).
ISSN
International Standard Serial Number.
Jurisdiction
Geographic scope of relevance (e.g. “US” for a US patent; the court hearing a legal case).
Keyword
Keyword(s) or tag(s) attached to the item.
Language
The language of the item.
License
The license information applicable to an item (e.g. the license an article or software is released under; the copyright information for an item; the classification status of a document).
Medium
Description of the item’s format or medium (e.g. “CD”, “DVD”, “Album”, etc.).
Note
Descriptive text or notes about an item (e.g. in an annotated bibliography).
OriginalPublisher
Original publisher, for items that have been republished by a different publisher.
OriginalPublisherPlace
Geographic location of the original publisher (e.g. “London, UK”).
OriginalTitle
Title of the original version (e.g. “Война и мир”, the untranslated Russian title of “War and Peace”).
PartTitle
Title of the specific part of an item being cited.
PMCID
PubMed Central reference number.
PMID
PubMed reference number.
Publisher
Publisher.
PublisherPlace
Geographic location of the publisher.
References
Resources related to the procedural history of a legal case or legislation; Can also be used to refer to the procedural history of other items (e.g. “Conference canceled” for a presentation accepted as a conference that was subsequently canceled; details of a retraction or correction notice).
ReviewedGenre
Type of the item being reviewed by the current item (e.g. book, film).
ReviewedTitle
Title of the item reviewed by the current item.
Scale
Scale of e.g. a map or model.
Source from whence the item originates (e.g. a library catalog or database).
Status
Publication status of the item (e.g. “forthcoming”; “in press”; “advance online publication”; “retracted”).
Title
Primary title of the item.
TitleShort
Short/abbreviated form of title; Deprecated; use variable=“title” form=“short” instead.
URL
Uniform Resource Locator (e.g. “https://aem.asm.org/cgi/content/full/74/9/2766”).
VolumeTitle
Title of the volume of the item or container holding the item; Also use for titles of periodical special issues, special sections, and the like.
YearSuffix
Disambiguating year suffix in author-date styles (e.g. “a” in “Doe, 1999a”).